@@ -200,8 +200,10 @@ def get_runtime_from_python_version():
             return "python3.6"
         elif sys.version_info[1] <= 7:
             return "python3.7"
-        else:
+        elif sys.version_info[1] <= 8:
             return "python3.8"
+        else:
+            return "python3.9"
 
 
 ##
